@@ -3,9 +3,9 @@ context("Google map")
 test_that("default options are set", {
 
   g <- google_map(key = "abc", location = NULL, zoom = NULL, search_box = F, styles = NULL)
-  expect_true(g$x$zoom == 8)
-  expect_true(g$x$lat == -37.9)
-  expect_true(g$x$lng == 144.5)
+  expect_true(g$x$zoom == 1)
+  expect_true(g$x$lat == 0)
+  expect_true(g$x$lng == 0)
   expect_false(g$x$search_box)
   expect_null(g$x$styles)
   expect_true(g$dependencies[[1]]$head == "<script src=\"https://maps.googleapis.com/maps/api/js?key=abc&libraries=visualization,geometry,places,drawing\"></script><script type=\"text/javascript\" src=\"https://www.gstatic.com/charts/loader.js\"></script>")
@@ -40,7 +40,8 @@ test_that("attributes and map data is attached", {
   expect_true(
     all(
       attributes(g$x)$names ==
-        c("lat", "lng","zoom","styles","search_box", "update_map_view", "zoomControl",
+        c("lat", "lng","zoom", "min_zoom", "max_zoom","mapBounds","styles","search_box",
+          "update_map_view", "zoomControl",
           "mapType", "mapTypeControl", "scaleControl", "streetViewControl", "rotateControl",
           "fullscreenControl","event_return_type", "split_view", "split_view_options",
           "geolocation")
